#
# spec file for package perl-Audio-Scan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Audio-Scan
Name:           perl-Audio-Scan
Version:        1.10.0
Release:        1699.6.pm.7
# 1.01 -> normalize -> 1.10.0
%define cpan_version 1.01
#Upstream: GPL-1.0-or-later
License:        GPL-2.0-or-later
Summary:        Fast C metadata and tag reader for all common audio file formats
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AG/AGRUNDMA/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Warn)
Requires:       perl(Test::Warn)
Provides:       perl(Audio::Scan) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  zlib-devel pkgconfig
# MANUAL END

%description
Audio::Scan is a C-based scanner for audio file metadata and tag
information. It currently supports MP3, MP4, Ogg Vorbis, FLAC, ASF, WAV,
AIFF, Musepack, Monkey's Audio, and WavPack.

See below for specific details about each file format.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.win32
%doc COPYING

%changelog
* Wed Jul 11 2018 coolo@suse.com
- updated to 1.01
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
* Mon Apr 23 2018 coolo@suse.com
- updated to 1.00
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
* Sun Dec 10 2017 coolo@suse.com
- updated to 0.99
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  0.99    2017-11-24
  - Fixed a bug where an incorrect audio offset was returned when using
    NO_ARTWORK and reading a file with an ID3v2.2 or v2.3 unsynchronization bit
    set. The artwork in this type of file is only available when scanning in
    normal mode (without NO_ARTWORK).
  - Added id3_was_unsynced => 1 to the info section for v2.2/v2.3 files with the
    whole-tag unsync bit set. This type of tag is generally harmful to parser performance,
    so this flag might be useful if you want to find and upgrade this type of tag to v2.4.
  - DSF: WAV_BLOCK_SIZE was being used instead of DSF_BLOCK_SIZE. (Kimmo Taskinen)
  - ID3: Support for reading ID3 tags located >4GB into a file, such as in very large
    DSF files. (Kimmo Taskinen)
  - WavPack: Read correct samplerate and bits_per_sample for DSD files. (Kimmo Taskinen)
  - DSF/DFF: added bitrate to info hash.
* Wed May  3 2017 coolo@suse.com
- updated to 0.98
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  0.98    2017-04-28
  - RT #119101, stop including MYMETA files in the tarball.
* Fri Apr 28 2017 coolo@suse.com
- updated to 0.97
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  0.97    2017-04-27
  - WAV: GH #2, fixed an integer overflow error that could result in an incorrect song_length_ms
    for >16-bit files.
* Thu Nov 24 2016 coolo@suse.com
- updated to 0.96
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
* Wed Nov 23 2016 coolo@suse.com
- updated to 0.96
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  0.96    2016-11-21
  - Ogg: RT #118888, fixed crash when trying to read Vorbis comments in an
    incorrectly framed file with a bad terminal header page.
  - Removed hints/darwin.pl, don't try to be smarter than Perl about how to build things.
  - Fixed various minor compiler warnings output by the latest clang on macOS.
  0.95    Unreleased community build
  - Improved DFF parsing for files which end with corrupted chunk. (Adrian Smith)
  - Improved ID3 support for DFF files. (Adrian Smith)
  0.94    Unreleased community build
  - DSF/DFF: Support dsd file scanning for dsd and dsdiff files. (Kimmo Taskinen)
  - AIFF: Fixed scanning of 24 bit files. (Adrian Smith)
* Fri Apr 17 2015 coolo@suse.com
- updated to 0.93
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  Note: Bug numbers refer to bugs at http://bugs.slimdevices.com
  0.93    2011-09-14
  - ASF: Support seeking in a file without an ASF_Index object.
  - Don't use MAX_PATH because this limits path names to only 260 chars on Win32.
  0.92    2011-09-09
  - Added $info->{jenkins_hash} which is a 32-bit hash value of the
    filename + mtime + file size.
  - MP4: Get correct HE-AAC samplerate values from esds.
  - ADTS AAC: Add support for .adts file extension.
  0.91    2011-09-06
  - MP3, MP4, WMA, WAV, AIFF, ADTS AAC: Added DLNA audio profile detection as
    $info->{dlna_profile}.
  0.90    2011-08-03
  - ID3: Bug 17392, fixed APIC offset calculation for non-MP3 files such as AIFF
    and WAV where the tag does not live at the front of the file.
  0.89    2011-08-03
  - APE: Bug 15895, better handling if we have a broken APE tag and run out of
    tag data. (Adrian Smith)
  - WMA: Bug 17355, fixed WM/Picture offset calculation when artwork is stored in the
    Header Extension/Metadata Library block.
  - WMA: Added output warning when trying to seek in a file without ASF_Index.
  - Switched aac.t to Test::Warn instead of manual STDERR redirection.
  0.88    2011-07-20
  - ADTS AAC: Check first 2-3 frames to avoid false syncs.
  - OSX: Xcode 4 doesn't include the 10.5 SDK, so check for this before using it.
  - Win32: Display better error messages when unable to read from files.
  - MP3, AAC, MPC: Bug 17173: Cleaned up several places where invalid memory reads could occur.
* Fri Apr 17 2015 coolo@suse.com
- updated to 0.93
  see /usr/share/doc/packages/perl-Audio-Scan/Changes
  Note: Bug numbers refer to bugs at http://bugs.slimdevices.com
  0.93    2011-09-14
  - ASF: Support seeking in a file without an ASF_Index object.
  - Don't use MAX_PATH because this limits path names to only 260 chars on Win32.
  0.92    2011-09-09
  - Added $info->{jenkins_hash} which is a 32-bit hash value of the
    filename + mtime + file size.
  - MP4: Get correct HE-AAC samplerate values from esds.
  - ADTS AAC: Add support for .adts file extension.
  0.91    2011-09-06
  - MP3, MP4, WMA, WAV, AIFF, ADTS AAC: Added DLNA audio profile detection as
    $info->{dlna_profile}.
  0.90    2011-08-03
  - ID3: Bug 17392, fixed APIC offset calculation for non-MP3 files such as AIFF
    and WAV where the tag does not live at the front of the file.
  0.89    2011-08-03
  - APE: Bug 15895, better handling if we have a broken APE tag and run out of
    tag data. (Adrian Smith)
  - WMA: Bug 17355, fixed WM/Picture offset calculation when artwork is stored in the
    Header Extension/Metadata Library block.
  - WMA: Added output warning when trying to seek in a file without ASF_Index.
  - Switched aac.t to Test::Warn instead of manual STDERR redirection.
  0.88    2011-07-20
  - ADTS AAC: Check first 2-3 frames to avoid false syncs.
  - OSX: Xcode 4 doesn't include the 10.5 SDK, so check for this before using it.
  - Win32: Display better error messages when unable to read from files.
  - MP3, AAC, MPC: Bug 17173: Cleaned up several places where invalid memory reads could occur.
* Mon Mar 21 2011 pascal.bleser@opensuse.org
- update to 0.87:
  * AAC: bug 16874: fixed infinite loop that could occur when reading a
    truncated ADTS stream
* Fri Mar 18 2011 pascal.bleser@opensuse.org
- initial version (0.86)
